do_keyfile: Get the default DigitalOcean SSH keyfile path
Description
Returns the path to the SSH private key for "digitalocean.com" from
ssh::ssh_key_info(). This is used as the default keyfile for all
buoyant functions that interact with DigitalOcean droplets.
Usage
do_keyfile()
Arguments
Value
A character string with the path to the SSH private key, or NULL
if no key is found.